Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/alembic/intern/abc_mball.h')
-rw-r--r--source/blender/alembic/intern/abc_mball.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/source/blender/alembic/intern/abc_mball.h b/source/blender/alembic/intern/abc_mball.h
index 629a584e89e..18ceda01f87 100644
--- a/source/blender/alembic/intern/abc_mball.h
+++ b/source/blender/alembic/intern/abc_mball.h
@@ -22,24 +22,21 @@
#define __ABC_MBALL_H__
#include "abc_object.h"
+#include "abc_mesh.h"
-class AbcMeshWriter;
struct EvaluationContext;
struct Main;
struct MetaBall;
struct Object;
/* AbcMBallWriter converts the metaballs to meshes at every frame,
* and defers to a wrapped AbcMeshWriter to perform the writing
* to the Alembic file. Only the basis balls are exported, as this
* results in the entire shape as one mesh. */
-class AbcMBallWriter : public AbcObjectWriter {
- AbcMeshWriter *m_mesh_writer;
- Object *m_mesh_ob;
- bool m_is_animated;
+class AbcMBallWriter : public AbcGenericMeshWriter {
Main *m_bmain;
public:
- AbcMBallWriter(
+ explicit AbcMBallWriter(
Main *bmain,
Object *ob,
AbcTransformWriter *parent,
@@ -50,8 +47,11 @@ public:
static bool isBasisBall(Scene *scene, Object *ob);
+protected:
+ Mesh *getEvaluatedMesh(Scene *scene_eval, Object *ob_eval, bool &r_needsfree) override;
+ void freeEvaluatedMesh(struct Mesh *mesh) override;
+
private:
- virtual void do_write();
bool isAnimated() const;
};
@@ -22,24 +22,21 @@
struct Object;
/* AbcMBallWriter converts the metaballs to meshes at every frame,
- * and defers to a wrapped AbcMeshWriter to perform the writing
+ * and defers to AbcGenericMeshWriter to perform the writing
* to the Alembic file. Only the basis balls are exported, as this
* results in the entire shape as one mesh. */